##  Prerequisites
Before you start, do the following:
  * Get an API token by creating a technical user. For more information, see [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users?locale=en-US&state=PRODUCTION&version=CLOUD "To get an API token, create a technical user. Manage technical users collaboratively with other administrators.").
  * Prepare the total annual cost data to be imported.


This tutorial assumes you have basic knowledge of:
  * Python
  * GraphQL
  * Fact sheets in SAP LeanIX
